"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.zodFilterQuery = zodFilterQuery;
const zod_1 = require("zod");
const nestjs_shared_1 = require("../../../../utils/nestjs-shared");
const types_1 = require("../../types");
const zod_utils_1 = require("../zod-utils");
const zodRuleForString = zod_1.z.union([
    zod_1.z.literal('null').transform(() => null),
    zod_1.z.string().refine((0, zod_utils_1.stringLongerThan)(), {
        message: 'String should be not empty',
    }),
]);
const zodRuleStringArray = zodRuleForString
    .array()
    .nonempty()
    .refine((0, zod_utils_1.arrayItemStringLongerThan)(0), {
    message: 'Array should be not empty',
});
const zodNullRule = zod_1.z.union([
    zod_1.z.literal('null'),
    zod_1.z.literal(null).transform((r) => 'null'),
]);
const zodRuleFilterRelationSchema = zod_1.z.union([
    zod_1.z
        .object({
        [nestjs_shared_1.FilterOperand.eq]: zodNullRule,
    })
        .strict(),
    zod_1.z
        .object({
        [nestjs_shared_1.FilterOperand.ne]: zodNullRule,
    })
        .strict(),
]);
const zodRuleForArrayField = zod_1.z
    .object({ [nestjs_shared_1.FilterOperand.some]: zodRuleStringArray })
    .strict();
function getZodRulesForField(type = types_1.TypeField.string) {
    const simpleShape = nestjs_shared_1.ObjectTyped.entries(nestjs_shared_1.FilterOperandOnlySimple).reduce((acum, [key, val]) => ({
        ...acum,
        [val]: zodRuleForString
            .refine((0, zod_utils_1.stringMustBe)(type), {
            message: `String should be as ${type}`,
        })
            .optional(),
    }), {});
    const ninInShape = nestjs_shared_1.ObjectTyped.entries(nestjs_shared_1.FilterOperandOnlyInNin).reduce((acum, [key, val]) => ({
        ...acum,
        [val]: zodRuleStringArray
            .refine((0, zod_utils_1.elementOfArrayMustBe)(type), {
            message: `String should be as ${type}`,
        })
            .optional(),
    }), {});
    return zod_1.z
        .object({
        ...simpleShape,
        ...ninInShape,
    })
        .strict()
        .refine((0, zod_utils_1.oneOf)(Object.values(nestjs_shared_1.FilterOperand).filter((i) => i !== nestjs_shared_1.FilterOperand.some)), {
        message: `Must have one of: "${Object.values(nestjs_shared_1.FilterOperand)
            .filter((i) => i !== nestjs_shared_1.FilterOperand.some)
            .join('","')}"`,
    });
}
function getFilterPropsShapeForEntity(fields, propsArrayTarget, propsType) {
    return fields.reduce((acum, field) => ({
        ...acum,
        [field]: (Reflect.get(propsArrayTarget, field)
            ? zodRuleForArrayField
            : getZodRulesForField(propsType[field])).optional(),
    }), {});
}
function getZodRulesForRelationShape(shape) {
    return zod_1.z.object(shape).strict().optional().refine((0, zod_utils_1.nonEmptyObject)());
}
function zodFilterQuery(fields, relationTree, propsArray, propsType) {
    const { target: propsArrayTarget, ...otherRelationPropsArray } = propsArray;
    const fieldsFilterProps = getFilterPropsShapeForEntity(fields, propsArrayTarget, propsType);
    const targetRelation = nestjs_shared_1.ObjectTyped.keys(relationTree).reduce((acum, item) => ({
        ...acum,
        [item]: zodRuleFilterRelationSchema.optional(),
    }), {});
    const relationFilterProps = nestjs_shared_1.ObjectTyped.keys(relationTree).reduce((acum, name) => {
        (0, zod_utils_1.guardIsKeyOfObject)(otherRelationPropsArray, name);
        const relationField = relationTree[name];
        const relationPropsArray = otherRelationPropsArray[name];
        const relationPropsType = propsType[name];
        const filterProps = getFilterPropsShapeForEntity(relationField, relationPropsArray, relationPropsType);
        const zodFilter = getZodRulesForRelationShape(filterProps);
        return {
            ...acum,
            [name]: zodFilter.optional(),
        };
    }, {});
    const targetShapeFilter = {
        target: zod_1.z
            .object({
            ...fieldsFilterProps,
            ...targetRelation,
        })
            .strict()
            .optional()
            .refine((0, zod_utils_1.nonEmptyObject)())
            .nullable(),
        relation: zod_1.z
            .object(relationFilterProps)
            .strict()
            .optional()
            .refine((0, zod_utils_1.nonEmptyObject)())
            .nullable(),
    };
    return zod_1.z.object(targetShapeFilter).strict().refine((0, zod_utils_1.nonEmptyObject)());
}
//# sourceMappingURL=filter.js.map