"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CurrentDataSourceProvider = CurrentDataSourceProvider;
exports.CurrentEntityManager = CurrentEntityManager;
exports.CurrentEntityRepository = CurrentEntityRepository;
exports.EntityPropsMap = EntityPropsMap;
exports.FindOneRowEntityFactory = FindOneRowEntityFactory;
exports.CheckRelationNameFactory = CheckRelationNameFactory;
exports.RunInTransactionFactory = RunInTransactionFactory;
exports.OrmServiceFactory = OrmServiceFactory;
const typeorm_1 = require("@nestjs/typeorm");
const nestjs_shared_1 = require("../../../utils/nestjs-shared");
const constants_1 = require("../../../constants");
const service_1 = require("../service");
const helper_1 = require("../../mixin/helper");
const orm_helper_1 = require("../orm-helper");
function CurrentDataSourceProvider(connectionName) {
    return {
        provide: constants_1.CURRENT_DATA_SOURCE_TOKEN,
        useFactory: (dataSource) => dataSource,
        inject: [(0, typeorm_1.getDataSourceToken)(connectionName)],
    };
}
function CurrentEntityManager() {
    return {
        provide: constants_1.CURRENT_ENTITY_MANAGER_TOKEN,
        useFactory: (dataSource) => dataSource.manager,
        inject: [constants_1.CURRENT_DATA_SOURCE_TOKEN],
    };
}
function CurrentEntityRepository(entity) {
    return {
        provide: constants_1.CURRENT_ENTITY_REPOSITORY,
        useFactory: (entityManager) => entityManager.getRepository(entity),
        inject: [constants_1.CURRENT_ENTITY_MANAGER_TOKEN],
    };
}
function EntityPropsMap(entities) {
    return {
        provide: constants_1.ENTITY_MAP_PROPS,
        inject: [constants_1.CURRENT_ENTITY_MANAGER_TOKEN],
        useFactory: (entityManager) => {
            const mapProperty = new Map();
            for (const item of entities) {
                const entityRepo = entityManager.getRepository(item);
                const className = (0, helper_1.getEntityName)(item);
                mapProperty.set(item, {
                    props: (0, orm_helper_1.getProps)(entityRepo),
                    propsType: (0, orm_helper_1.getPropsType)(entityRepo),
                    propsNullable: (0, orm_helper_1.getPropsNullable)(entityRepo),
                    primaryColumnName: (0, orm_helper_1.getPrimaryColumnName)(entityRepo),
                    primaryColumnType: (0, orm_helper_1.getPrimaryColumnType)(entityRepo),
                    typeName: (0, nestjs_shared_1.camelToKebab)(className),
                    className: className,
                    relations: (0, orm_helper_1.getRelation)(entityRepo),
                    relationProperty: (0, orm_helper_1.getRelationProperty)(entityRepo),
                });
            }
            return mapProperty;
        },
    };
}
function FindOneRowEntityFactory() {
    return {
        provide: constants_1.FIND_ONE_ROW_ENTITY,
        inject: [constants_1.CURRENT_ENTITY_REPOSITORY, service_1.TypeormUtilsService],
        useFactory: (repository, typeormUtilsService) => {
            return async (entity, value) => {
                const params = 'params';
                return await repository
                    .createQueryBuilder(typeormUtilsService.currentAlias)
                    .where(`${typeormUtilsService.getAliasPath(typeormUtilsService.currentPrimaryColumn)} = :${params}`)
                    .setParameters({
                    [params]: value,
                })
                    .getOne();
            };
        },
    };
}
function CheckRelationNameFactory() {
    return {
        provide: constants_1.CHECK_RELATION_NAME,
        inject: [service_1.TypeormUtilsService],
        useFactory(typeormUtilsService) {
            return (entity, value) => !!typeormUtilsService.relationFields.find((i) => i === value);
        },
    };
}
function RunInTransactionFactory() {
    return {
        provide: constants_1.RUN_IN_TRANSACTION_FUNCTION,
        inject: [constants_1.GLOBAL_MODULE_OPTIONS_TOKEN, constants_1.CURRENT_DATA_SOURCE_TOKEN],
        useFactory(options, dataSource) {
            const { options: { runInTransaction }, } = options;
            if (runInTransaction && typeof runInTransaction === 'function') {
                return (callback) => runInTransaction('READ COMMITTED', () => callback());
            }
            return async (callback) => {
                const queryRunner = dataSource.createQueryRunner();
                await queryRunner.startTransaction('READ UNCOMMITTED');
                let result;
                try {
                    result = await callback();
                    await queryRunner.commitTransaction();
                }
                catch (e) {
                    await queryRunner.rollbackTransaction();
                    throw e;
                }
                finally {
                    await queryRunner.release();
                }
                return result;
            };
        },
    };
}
function OrmServiceFactory() {
    return {
        provide: constants_1.ORM_SERVICE,
        useClass: service_1.TypeOrmService,
    };
}
//# sourceMappingURL=index.js.map