import { Repository } from 'typeorm';
import { ObjectLiteral } from '../../../types';
import { RelationTree, ValueOf, UnionToTuple, TypeCast, Concat, TypeOfArray, PropsNameResultField, PropsArray, ResultGetField, ArrayPropsForEntity, AllFieldWithType, FieldWithType, RelationPropsArray, TypeForId, PropsForField, RelationPropsTypeName, RelationPrimaryColumnType, TupleOfEntityRelation, TupleOfEntityProps, FilterNullableProps, RelationProperty } from '../../mixin/types';
export type ConcatFieldWithRelation<R extends string, T extends readonly string[]> = ValueOf<{
    [K in T[number]]: Concat<R, K>;
}>;
export type ConcatRelationUnion<E extends ObjectLiteral, R = RelationTree<E>> = ValueOf<{
    [K in keyof R]: ConcatFieldWithRelation<TypeCast<K, string>, TypeCast<R[K], readonly string[]>>;
}>;
export type ConcatRelation<E extends ObjectLiteral> = TypeCast<UnionToTuple<ConcatRelationUnion<E>>, [
    string,
    ...string[]
]>;
export declare const getField: <E extends ObjectLiteral>(repository: Repository<E>) => ResultGetField<E>;
export declare const fromRelationTreeToArrayName: <E extends ObjectLiteral>(relationTree: RelationTree<E>) => ConcatRelation<E>;
export declare const getPropsTreeForRepository: <E extends ObjectLiteral>(repository: Repository<E>) => RelationTree<E>;
export type PropertyTarget<E extends ObjectLiteral, For extends PropsNameResultField> = {
    [K in ResultGetField<E>[For][number]]: K extends keyof E ? TypeOfArray<E[K]> : never;
};
export declare function guardKeyForPropertyTarget<E extends ObjectLiteral, For extends PropsNameResultField, R extends PropertyTarget<E, For>>(relationsTargets: R, key: any): asserts key is keyof R;
export declare const getArrayPropsForEntity: <E extends ObjectLiteral>(repository: Repository<E>) => ArrayPropsForEntity<E>;
export declare const getArrayFields: <E extends ObjectLiteral>(repository: Repository<E>) => PropsArray<E>;
export declare const getTypeForAllProps: <E extends ObjectLiteral>(repository: Repository<E>) => AllFieldWithType<E>;
export declare const getFieldWithType: <E extends ObjectLiteral>(repository: Repository<E>) => FieldWithType<E>;
export declare const getRelationTypeArray: <E extends ObjectLiteral>(repository: Repository<E>) => RelationPropsArray<E>;
export declare const getTypePrimaryColumn: <E extends ObjectLiteral>(repository: Repository<E>) => TypeForId;
export declare const getPropsFromDb: <E extends ObjectLiteral>(repository: Repository<E>) => PropsForField<E>;
export declare const getRelationTypeName: <E extends ObjectLiteral>(repository: Repository<E>) => RelationPropsTypeName<E>;
export declare const getRelationTypePrimaryColumn: <E extends ObjectLiteral>(repository: Repository<E>) => RelationPrimaryColumnType<E>;
export declare const getRelation: <E extends ObjectLiteral>(repository: Repository<E>) => TupleOfEntityRelation<E>;
export declare const getProps: <E extends ObjectLiteral>(repository: Repository<E>) => TupleOfEntityProps<E>;
export declare const getPropsType: <E extends ObjectLiteral>(repository: Repository<E>) => FieldWithType<E>;
export declare const getPropsNullable: <E extends ObjectLiteral>(repository: Repository<E>) => FilterNullableProps<E, TupleOfEntityProps<E>>;
export declare const getPrimaryColumnName: <E extends ObjectLiteral>(repository: Repository<E>) => string;
export declare const getPrimaryColumnType: <E extends ObjectLiteral>(repository: Repository<E>) => TypeForId;
export declare const getRelationProperty: <E extends ObjectLiteral>(repository: Repository<E>) => RelationProperty<E>;
