"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRelationProperty = exports.getPrimaryColumnType = exports.getPrimaryColumnName = exports.getPropsNullable = exports.getPropsType = exports.getProps = exports.getRelation = exports.getRelationTypePrimaryColumn = exports.getRelationTypeName = exports.getPropsFromDb = exports.getTypePrimaryColumn = exports.getRelationTypeArray = exports.getFieldWithType = exports.getTypeForAllProps = exports.getArrayFields = exports.getArrayPropsForEntity = exports.getPropsTreeForRepository = exports.fromRelationTreeToArrayName = exports.getField = void 0;
exports.guardKeyForPropertyTarget = guardKeyForPropertyTarget;
const nestjs_shared_1 = require("../../../utils/nestjs-shared");
const types_1 = require("../../mixin/types");
const helper_1 = require("../../mixin/helper");
const getField = (repository) => {
    const relations = repository.metadata.relations.map((i) => {
        return i.propertyName;
    });
    const field = repository.metadata.columns
        .filter((i) => !relations.includes(i.propertyName))
        .map((r) => r.propertyName);
    return {
        field,
        relations,
    };
};
exports.getField = getField;
const fromRelationTreeToArrayName = (relationTree) => {
    return nestjs_shared_1.ObjectTyped.entries(relationTree).reduce((acum, [name, filed]) => {
        acum.push(...filed.map((i) => `${name.toLocaleString()}.${i}`));
        return acum;
    }, []);
};
exports.fromRelationTreeToArrayName = fromRelationTreeToArrayName;
const getPropsTreeForRepository = (repository) => {
    const dataSource = repository.metadata.connection;
    const relationType = repository.metadata.relations.reduce((acum, i) => {
        acum[i.propertyName] = i.inverseEntityMetadata.target;
        return acum;
    }, {});
    return nestjs_shared_1.ObjectTyped.entries(relationType).reduce((acum, [key, value]) => ({
        ...acum,
        ...{ [key]: (0, exports.getField)(dataSource.getRepository(value))['field'] },
    }), {});
};
exports.getPropsTreeForRepository = getPropsTreeForRepository;
function guardKeyForPropertyTarget(relationsTargets, key) {
    if (!(key in relationsTargets))
        throw new Error('Type guard error');
}
const getArrayPropsForEntity = (repository) => {
    const connection = repository.metadata.connection;
    const relationsTargets = repository.metadata.relations.reduce((acum, i) => ({
        ...acum,
        [i.propertyName]: i.type,
    }), {});
    const { relations } = (0, exports.getField)(repository);
    const relationsArrayFields = relations.reduce((acum, item) => {
        guardKeyForPropertyTarget(relationsTargets, item);
        const target = relationsTargets[item];
        const repository = connection.getRepository(target);
        acum[item] = (0, exports.getArrayFields)(repository);
        return acum;
    }, {});
    return {
        target: (0, exports.getArrayFields)(repository),
        ...relationsArrayFields,
    };
};
exports.getArrayPropsForEntity = getArrayPropsForEntity;
const getArrayFields = (repository) => {
    const relations = repository.metadata.relations.map((i) => {
        return i.propertyName;
    });
    return repository.metadata.columns
        .filter((i) => !relations.includes(i.propertyName))
        .reduce((acum, metaData) => {
        if (metaData.isArray) {
            acum[metaData.propertyName] = true;
        }
        return acum;
    }, {});
};
exports.getArrayFields = getArrayFields;
const getTypeForAllProps = (repository) => {
    const targetField = (0, exports.getFieldWithType)(repository);
    const relationField = repository.metadata.relations.reduce((acum, item) => {
        acum[item.propertyName] = (0, exports.getFieldWithType)(repository.manager.getRepository(item.inverseEntityMetadata.target));
        return acum;
    }, {});
    return {
        ...targetField,
        ...relationField,
    };
};
exports.getTypeForAllProps = getTypeForAllProps;
const getFieldWithType = (repository) => {
    const { field } = (0, exports.getField)(repository);
    const entity = repository.target;
    const result = {};
    for (const item of field) {
        let typeProps = types_1.TypeField.string;
        switch (Reflect.getMetadata('design:type', entity['prototype'], item)) {
            case Array:
                typeProps = types_1.TypeField.array;
                break;
            case Date:
                typeProps = types_1.TypeField.date;
                break;
            case Number:
                typeProps = types_1.TypeField.number;
                break;
            case Boolean:
                typeProps = types_1.TypeField.boolean;
                break;
            case Object:
                typeProps = types_1.TypeField.object;
                break;
            default:
                typeProps = types_1.TypeField.string;
        }
        result[item] = typeProps;
    }
    return result;
};
exports.getFieldWithType = getFieldWithType;
const getRelationTypeArray = (repository) => {
    const { relations } = (0, exports.getField)(repository);
    const entity = repository.target;
    const result = {};
    for (const item of relations) {
        result[item] =
            Reflect.getMetadata('design:type', entity['prototype'], item) === Array;
    }
    return result;
};
exports.getRelationTypeArray = getRelationTypeArray;
const getTypePrimaryColumn = (repository) => {
    const target = repository.target;
    const primaryColumn = repository.metadata.primaryColumns[0].propertyName;
    return Reflect.getMetadata('design:type', target['prototype'], primaryColumn) === Number
        ? types_1.TypeField.number
        : types_1.TypeField.string;
};
exports.getTypePrimaryColumn = getTypePrimaryColumn;
const getPropsFromDb = (repository) => {
    return repository.metadata.columns.reduce((acum, i) => {
        const tmp = i.propertyName;
        acum[tmp] = {
            type: i.type,
            isArray: i.isArray,
            isNullable: i.isNullable || i.default !== undefined,
        };
        return acum;
    }, {});
};
exports.getPropsFromDb = getPropsFromDb;
const getRelationTypeName = (repository) => {
    return repository.metadata.relations.reduce((acum, i) => {
        acum[i.propertyName] = (0, helper_1.getEntityName)(i.inverseEntityMetadata.target);
        return acum;
    }, {});
};
exports.getRelationTypeName = getRelationTypeName;
const getRelationTypePrimaryColumn = (repository) => {
    return repository.metadata.relations.reduce((acum, i) => {
        const target = i.inverseEntityMetadata.target;
        const primaryColumn = i.inverseEntityMetadata.primaryColumns[0].propertyName;
        acum[i.propertyName] =
            Reflect.getMetadata('design:type', target['prototype'], primaryColumn) ===
                Number
                ? types_1.TypeField.number
                : types_1.TypeField.string;
        return acum;
    }, {});
};
exports.getRelationTypePrimaryColumn = getRelationTypePrimaryColumn;
// -----
const getRelation = (repository) => repository.metadata.relations.map((i) => {
    return i.propertyName;
});
exports.getRelation = getRelation;
const getProps = (repository) => {
    const relations = (0, exports.getRelation)(repository);
    return repository.metadata.columns
        .filter((i) => !relations.includes(i.propertyName))
        .map((r) => r.propertyName);
};
exports.getProps = getProps;
const getPropsType = (repository) => {
    const field = (0, exports.getProps)(repository);
    const entity = repository.target;
    const result = {};
    for (const item of field) {
        let typeProps = types_1.TypeField.string;
        const fieldMetadata = repository.metadata.columns.find((i) => i.propertyName === item);
        if (fieldMetadata?.isArray) {
            result[item] = types_1.TypeField.array;
            continue;
        }
        switch (Reflect.getMetadata('design:type', entity['prototype'], item)) {
            case Array:
                typeProps = types_1.TypeField.array;
                break;
            case Date:
                typeProps = types_1.TypeField.date;
                break;
            case Number:
                typeProps = types_1.TypeField.number;
                break;
            case Boolean:
                typeProps = types_1.TypeField.boolean;
                break;
            case Object:
                typeProps = types_1.TypeField.object;
                break;
            default:
                typeProps = types_1.TypeField.string;
        }
        result[item] = fieldMetadata?.isArray ? types_1.TypeField.array : typeProps;
    }
    return result;
};
exports.getPropsType = getPropsType;
const getPropsNullable = (repository) => {
    const relation = (0, exports.getRelation)(repository);
    return repository.metadata.columns
        .filter((i) => !relation.includes(i.propertyName))
        .map((i) => i.isNullable || i.default !== undefined ? i.propertyName : false)
        .filter((i) => !!i);
};
exports.getPropsNullable = getPropsNullable;
const getPrimaryColumnName = (repository) => {
    const column = repository.metadata.primaryColumns.at(0);
    if (!column)
        throw new Error('Primary column not found');
    return column.propertyName;
};
exports.getPrimaryColumnName = getPrimaryColumnName;
const getPrimaryColumnType = (repository) => {
    const target = repository.target;
    const primaryColumn = repository.metadata.primaryColumns[0].propertyName;
    return Reflect.getMetadata('design:type', target['prototype'], primaryColumn) === Number
        ? types_1.TypeField.number
        : types_1.TypeField.string;
};
exports.getPrimaryColumnType = getPrimaryColumnType;
const getRelationProperty = (repository) => {
    return repository.metadata.relations.reduce((acum, item) => {
        // @ts-expect-error its dynamic creater
        acum[item.propertyName] = {
            entityClass: item.inverseEntityMetadata.target,
            nullable: item.isManyToMany || item.isOneToMany ? false : item.isNullable,
            isArray: item.isManyToMany || item.isOneToMany,
        };
        return acum;
    }, {});
};
exports.getRelationProperty = getRelationProperty;
//# sourceMappingURL=index.js.map