import { ResourceObject, EntityRelation, ResourceObjectRelationships } from '../../../utils/nestjs-shared';
import { Repository } from 'typeorm';
import { OrmService } from '../../mixin/types';
import { PatchData, PatchRelationshipData, PostData, PostRelationshipData, Query, QueryOne } from '../../mixin/zod';
import { ConfigParam, ObjectLiteral } from '../../../types';
import { TypeormUtilsService } from './typeorm-utils.service';
import { JsonApiTransformerService } from '../../mixin/service/json-api-transformer.service';
import { TypeOrmParam } from '../type';
export declare class TypeOrmService<E extends ObjectLiteral> implements OrmService<E> {
    typeormUtilsService: TypeormUtilsService<E>;
    transformDataService: JsonApiTransformerService<E>;
    config: ConfigParam & TypeOrmParam;
    repository: Repository<E>;
    getAll(query: Query<E>): Promise<ResourceObject<E, 'array'>>;
    deleteOne(id: number | string): Promise<void>;
    deleteRelationship<Rel extends EntityRelation<E>>(id: number | string, rel: Rel, input: PostRelationshipData): Promise<void>;
    getOne(id: number | string, query: QueryOne<E>): Promise<ResourceObject<E>>;
    getRelationship<Rel extends EntityRelation<E>>(id: number | string, rel: Rel): Promise<ResourceObjectRelationships<E, Rel>>;
    patchOne(id: number | string, inputData: PatchData<E>): Promise<ResourceObject<E>>;
    patchRelationship<Rel extends EntityRelation<E>>(id: number | string, rel: Rel, input: PatchRelationshipData): Promise<ResourceObjectRelationships<E, Rel>>;
    postOne(inputData: PostData<E>): Promise<ResourceObject<E>>;
    postRelationship<Rel extends EntityRelation<E>>(id: number | string, rel: Rel, input: PostRelationshipData): Promise<ResourceObjectRelationships<E, Rel>>;
}
